==> php54-owncloud-8.0.4.tgz: share/owncloud/apps/files_sharing/l10n/sv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server-till-server-delning är inte aktiverat på denna server",
    "The mountpoint name contains invalid characters." : "Monteringspunktens namn innehåller ogiltiga tecken.",
    "Invalid or untrusted SSL certificate" : "Ogiltigt eller ej betrott SSL-certifikat",
    "Couldn't add remote share" : "Kunde inte lägga till fjärrutdelning",
    "Shared with you" : "Delat med dig",
    "Shared with others" : "Delat med andra",
    "Shared by link" : "Delad som länk",
    "Nothing shared with you yet" : "Inget delat med dig ännu",
    "Files and folders others share with you will show up here" : "Filer och mappar andra delar med dig kommer visas här",
    "Nothing shared yet" : "Inget delat ännu",
    "Files and folders you share will show up here" : "Filer och mappar du delar kommer visas här",
    "No shared links" : "Inga delade länkar",
    "Files and folders you share by link will show up here" : "Filer och mappar du delar som länkar kommer visas här",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vill du lägga till fjärrdelning {name} från {owner}@{remote}?",
    "Remote share" : "Fjärrdelning",
    "Remote share password" : "Lösenord för fjärrdelning",
    "Cancel" : "Avbryt",
    "Add remote share" : "Lägg till fjärrdelning",
    "Invalid ownCloud url" : "Felaktig ownCloud url",
    "Share" : "Dela",
    "Shared by" : "Delad av",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mapp delades från <strong>en annan server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "En publikt delad fil eller mapp blev <strong>nerladdad</strong>",
    "You received a new remote share from %s" : "Du mottog en ny fjärrdelning från %s",
    "%1$s accepted remote share %2$s" : "%1$s accepterade fjärrdelning %2$s",
    "%1$s declined remote share %2$s" : "%1$s nekade fjärrdelning %2$s",
    "%1$s unshared %2$s from you" : "%1$s tog bort delningen %2$s från dig",
    "Public shared folder %1$s was downloaded" : "Publikt delad mapp %1$s blev nerladdad",
    "Public shared file %1$s was downloaded" : "Publikt delad fil %1$s blev nerladdad",
    "This share is password-protected" : "Den här delningen är lösenordsskyddad",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Password" : "Lösenord",
    "Name" : "Namn",
    "Share time" : "Delningstid",
    "Sorry, this link doesn’t seem to work anymore." : "Tyvärr, denna länk verkar inte fungera längre.",
    "Reasons might be:" : "Orsaker kan vara:",
    "the item was removed" : "objektet togs bort",
    "the link expired" : "giltighet för länken har gått ut",
    "sharing is disabled" : "delning är inaktiverat",
    "For more info, please ask the person who sent this link." : "För mer information, kontakta den person som skickade den här länken.",
    "Add to your ownCloud" : "Lägg till i din ownCloud",
    "Download" : "Ladda ner",
    "Download %s" : "Ladda ner %s",
    "Direct link" : "Direkt länk",
    "Allow users on this server to send shares to other servers" : "Tillåt användare på denna server att skicka utdelningar till andra servrar",
    "Allow users on this server to receive shares from other servers" : "Tillåt användare på denna servern att ta emot utdelningar från andra servrar"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files_sharing/l10n/sv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server-till-server-delning är inte aktiverat på denna server",
    "The mountpoint name contains invalid characters." : "Monteringspunktens namn innehåller ogiltiga tecken.",
    "Invalid or untrusted SSL certificate" : "Ogiltigt eller ej betrott SSL-certifikat",
    "Couldn't add remote share" : "Kunde inte lägga till fjärrutdelning",
    "Shared with you" : "Delat med dig",
    "Shared with others" : "Delat med andra",
    "Shared by link" : "Delad som länk",
    "Nothing shared with you yet" : "Inget delat med dig ännu",
    "Files and folders others share with you will show up here" : "Filer och mappar andra delar med dig kommer visas här",
    "Nothing shared yet" : "Inget delat ännu",
    "Files and folders you share will show up here" : "Filer och mappar du delar kommer visas här",
    "No shared links" : "Inga delade länkar",
    "Files and folders you share by link will show up here" : "Filer och mappar du delar som länkar kommer visas här",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vill du lägga till fjärrdelning {name} från {owner}@{remote}?",
    "Remote share" : "Fjärrdelning",
    "Remote share password" : "Lösenord för fjärrdelning",
    "Cancel" : "Avbryt",
    "Add remote share" : "Lägg till fjärrdelning",
    "Invalid ownCloud url" : "Felaktig ownCloud url",
    "Share" : "Dela",
    "Shared by" : "Delad av",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mapp har <strong>delats</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mapp delades från <strong>en annan server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "En publikt delad fil eller mapp blev <strong>nerladdad</strong>",
    "You received a new remote share from %s" : "Du mottog en ny fjärrdelning från %s",
    "%1$s accepted remote share %2$s" : "%1$s accepterade fjärrdelning %2$s",
    "%1$s declined remote share %2$s" : "%1$s nekade fjärrdelning %2$s",
    "%1$s unshared %2$s from you" : "%1$s tog bort delningen %2$s från dig",
    "Public shared folder %1$s was downloaded" : "Publikt delad mapp %1$s blev nerladdad",
    "Public shared file %1$s was downloaded" : "Publikt delad fil %1$s blev nerladdad",
    "You shared %1$s with %2$s" : "Du delade %1$s med %2$s",
    "You shared %1$s with group %2$s" : "Du delade %1$s med grupp %2$s",
    "%2$s shared %1$s with you" : "%2$s delade %1$s med dig",
    "You shared %1$s via link" : "Du delade %1$s via länk",
    "Shares" : "Delningar",
    "This share is password-protected" : "Den här delningen är lösenordsskyddad",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Password" : "Lösenord",
    "Name" : "Namn",
    "Share time" : "Delningstid",
    "Sorry, this link doesn’t seem to work anymore." : "Tyvärr, denna länk verkar inte fungera längre.",
    "Reasons might be:" : "Orsaker kan vara:",
    "the item was removed" : "objektet togs bort",
    "the link expired" : "giltighet för länken har gått ut",
    "sharing is disabled" : "delning är inaktiverat",
    "For more info, please ask the person who sent this link." : "För mer information, kontakta den person som skickade den här länken.",
    "Add to your ownCloud" : "Lägg till i din ownCloud",
    "Download" : "Ladda ner",
    "Download %s" : "Ladda ner %s",
    "Direct link" : "Direkt länk",
    "Allow users on this server to send shares to other servers" : "Tillåt användare på denna server att skicka utdelningar till andra servrar",
    "Allow users on this server to receive shares from other servers" : "Tillåt användare på denna servern att ta emot utdelningar från andra servrar"
},
"nplurals=2; plural=(n != 1);");
